Downloads the FRA 2025 bulk data from the FAO-FRA website available at https://fra-data.fao.org/assessments/fra/2025/WO/data-download/ Removes month and date from the names of three main files (FRA_Years_2025, Intervals_2025 and Annual_2025.csv).
Downloads the FRA 2025 bulk data from the FAO-FRA website available at https://fra-data.fao.org/assessments/fra/2025/WO/data-download/ Removes month and date from the names of three main files (FRA_Years_2025, Intervals_2025 and Annual_2025.csv).