Calculates bilateral trade values based on FAO trade matrix
Usage
calcFAOBilateralTrade(
output = "value",
products = "kcr",
prodAgg = TRUE,
harmonize = FALSE,
fiveYear = TRUE
)Arguments
- output
"value", "qty", or "price"
- products
"kcr", "kli", or "kothers"
- prodAgg
binary to keep FAO product level or magpie
- harmonize
combine input and export sheets with harmonization algorithm based on reliability index(Gelhar 1996) default off as there are some big differences and perhaps using the import sheet is better overall i.e. more matching with massbal
- fiveYear
if TRUE calculate only 5 years (1995 to 2020, 5-year steps) to reduce memory load